@@ -1,4 +1,4 @@
-/* ANSI-C code produced by gperf version 3.2 */
+/* ANSI-C code produced by gperf version 3.3 */
 /* Command-line: gperf -m 10 unictype/combiningclass_byname.gperf  */
 /* Computed positions: -k'1,6,$' */
 
@@ -125,9 +125,9 @@ combining_class_hash (register const char *str, register size_t len)
     {
       default:
         hval += asso_values[(unsigned char)str[5]];
-#if defined __cplusplus && (__cplusplus >= 201703L || (__cplusplus >= 201103L && defined __clang_major__ && defined __clang_minor__ && __clang_major__ + (__clang_minor__ >= 9) > 3))
+#if (defined __cplusplus && (__cplusplus >= 201703L || (__cplusplus >= 201103L && defined __clang__ && __clang_major__ + (__clang_minor__ >= 9) > 3))) || (defined __STDC_VERSION__ && __STDC_VERSION__ >= 202000L && ((defined __GNUC__ && __GNUC__ >= 10) || (defined __clang__ && __clang_major__ >= 9)))
       [[fallthrough]];
-#elif defined __GNUC__ && __GNUC__ >= 7
+#elif (defined __GNUC__ && __GNUC__ >= 7) || (defined __clang__ && __clang_major__ >= 10)
       __attribute__ ((__fallthrough__));
 #endif
       /*FALLTHROUGH*/
@@ -256,6 +256,10 @@ static const struct combining_class_stringpool_t combining_class_stringpool_cont
   };
 #define combining_class_stringpool ((const char *) &combining_class_stringpool_contents)
 
+#if (defined __GNUC__ && __GNUC__ + (__GNUC_MINOR__ >= 6) > 4) || (defined __clang__ && __clang_major__ >= 3)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
+#endif
 static const struct named_combining_class combining_class_names[] =
   {
     {-1}, {-1}, {-1},
@@ -374,6 +378,9 @@ static const struct named_combining_class combining_class_names[] =
 #line 84 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str66, UC_CCC_DB}
   };
+#if (defined __GNUC__ && __GNUC__ + (__GNUC_MINOR__ >= 6) > 4) || (defined __clang__ && __clang_major__ >= 3)
+#pragma GCC diagnostic pop
+#endif
 
 static const struct named_combining_class *
 uc_combining_class_lookup (register const char *str, register size_t len)
@@ -394,5 +401,5 @@ uc_combining_class_lookup (register const char *str, register size_t len)
             }
         }
     }
-  return 0;
+  return (struct named_combining_class *) 0;
 }
